@@ -7,10 +7,10 @@ from . import Snapshot
 
 
 class HasCorrectItems(ExperimentTest):
-    '''Passes if a FREESURFER6 resource and expected files according to a given
-    list (see report) are found. Unknown items are reported unless identified
-    as hippocampal subfields (or related), "touch" or log files.
-    Fails if some expected files are found missing and returns a list.'''
+    """Passes if a FREESURFER6 resource and the expected files according to a
+    given list (see report) are found. Unknown items are reported unless
+    identified as hippocampal subfields (or related), "touch" or log files.
+    Fails if some expected files are found missing and returns a list."""
 
     passing = 'BBRCDEV_E00365',
     failing = 'BBRCDEV_E00251',
@@ -86,9 +86,8 @@ class HasCorrectItems(ExperimentTest):
 
 
 class HasCorrectFreeSurferVersion(ExperimentTest):
-    '''This test checks the FreeSurfer version used for processing the images.
-    Passes if FREESURFER6 outputs were built using an specific version
-    (`build-stamp.txt`); fails otherwise.'''
+    """This test checks the version of FreeSurfer used. Passes if FREESURFER6
+    outputs were created using the expected version (i.e. `v6.0.0-2beb96c`)."""
 
     passing = 'BBRCDEV_E00365',
     failing = 'BBRCDEV_E00251',
@@ -116,9 +115,9 @@ class HasCorrectFreeSurferVersion(ExperimentTest):
 
 
 class HasCorrectOSVersion(ExperimentTest):
-    '''This test checks the OS version on which FreeSurfer was executed for
-    processing the images.
-    Passes if OS version matches a baseline version; fails otherwise.'''
+    """This test checks the OS kernel version on which FreeSurfer was executed.
+    Passes if OS kernel version matches the expected version (i.e. `4.4.120-92.70`);
+    fails otherwise."""
 
     passing = 'BBRCDEV_E00013',
     failing = 'BBRCDEV_E00365',
@@ -147,14 +146,10 @@ class HasCorrectOSVersion(ExperimentTest):
 
 
 class IsT1OnlyHippocampalSegmentation(ExperimentTest):
-    '''Hippocampal Segmentation has three modes of operation, depending on
-    whether only T1 scan or additional MRI volume (any MRI contrast supported)
-    containing the hippocampus is used.
-    This test checks that FREESURFER6 resource has a valid T1-only (mode A)
-    hippocampal segmentation. Passes if all output files generated by
-    FreeSurfer's hippocampal segmentation procedure are present; fails
-    otherwise.
-    '''
+    """This test asserts that FREESURFER6 resource contains valid T1w-only (mode A)
+    hippocampal segmentation outputs. Passes if expected T1w-only output files
+    generated by FreeSurfer hippocampal segmentation procedure are found;
+    fails otherwise."""
 
     passing = 'BBRCDEV_E00365',
     failing = 'BBRCDEV_E00015',
@@ -202,10 +197,10 @@ class IsT1OnlyHippocampalSegmentation(ExperimentTest):
 
 
 class IsT1T2HippocampalSegmentation(ExperimentTest):
-    '''This test checks that FREESURFER6 resource has a valid T1+T2 (mode B)
-    multispectral hippocampal segmentation.
-    Passes if all output files generated by FreeSurfer's hippocampal
-    segmentation procedure are found; fails otherwise.'''
+    """This test asserts that FREESURFER6 resource contains T1w+T2w multispectral
+    (mode B) hippocampal segmentation outputs. Passes if expected T1w+T2w output
+    files generated by FreeSurfer hippocampal segmentation procedure are found;
+    fails otherwise."""
 
     passing = 'BBRCDEV_E00015',
     failing = 'BBRCDEV_E00365',
@@ -243,10 +238,10 @@ class IsT1T2HippocampalSegmentation(ExperimentTest):
 
 
 class IsT1IRHippocampalSegmentation(ExperimentTest):
-    ''' This test checks that FREESURFER6 resource has a valid T1+IR (mode B)
-     multispectral hippocampal segmentation.
-    Passes if all output files generated by FreeSurfer's hippocampal
-    segmentation procedure are found; fails otherwise.'''
+    """This test asserts that FREESURFER6 resource contains T1w+IR multispectral
+    (mode B) hippocampal segmentation outputs. Passes if expected T1w+IR output
+    files generated by FreeSurfer hippocampal segmentation procedure are found;
+    fails otherwise."""
 
     passing = 'BBRCDEV_E00399',
     failing = 'BBRCDEV_E00365',
@@ -284,11 +279,10 @@ class IsT1IRHippocampalSegmentation(ExperimentTest):
 
 
 class IsT2MultispectralHippoSegRunnable(ExperimentTest):
-    ''' Checks that the given MRSession fulfills the requirements for running
-    FreeSurfer's hippocampal segmentation in multispectral mode (mode B) by
-    using an additional T2W scan.
-    Fails if no MRSession scans are suited for running the segmentation in
-     multispectral mode, passes otherwise.'''
+    """This test checks that the given MRSession can run FreeSurfer's hippocampal
+    segmentation in multispectral mode (mode B) by using an additional T2W scan.
+    Fails if no T2w scans are available for running the hippocampal segmentation
+    in multispectral mode; passes otherwise."""
 
     passing = 'BBRCDEV_E00399',
     failing = 'BBRCDEV_E00365',
@@ -312,11 +306,10 @@ class IsT2MultispectralHippoSegRunnable(ExperimentTest):
 
 
 class IsIRMultispectralHippoSegRunnable(ExperimentTest):
-    ''' Checks that the given MRSession fulfills the requirements for running
-    FreeSurfer's hippocampal segmentation in multispectral mode (mode B) by
-     using an additional IR scan.
-    Fails if no MRSession scans are suited for running the segmentation in
-    multispectral mode, passes otherwise.'''
+    """This test checks that the given MRSession can run FreeSurfer's hippocampal
+    segmentation in multispectral mode (mode B) by using an additional IR scan.
+    Fails if no IR scans are available for running the hippocampal segmentation
+    in multispectral mode; passes otherwise."""
 
     passing = 'BBRCDEV_E00399',
     failing = 'BBRCDEV_E00365',
@@ -340,10 +333,10 @@ class IsIRMultispectralHippoSegRunnable(ExperimentTest):
 
 
 class IsFreeSurferTimewiseConsistent(ExperimentTest):
-    ''' Processing outputs should *always* be posterior to their input data.
+    """Processing outputs should *always* be posterior to their input data.
     This Test checks that FreeSurfer outputs are chronologically consistent
-    (i.e. newer than) with the insertion of the MRSession in XNAT and the
-    creation of the NIFTI converted image files.'''
+    with (i.e. newer than) the date of insertion of the MRSession in XNAT and
+    the date of creation of the NIFTI converted image files."""
 
     passing = 'BBRCDEV_E00013',
     failing = 'BBRCDEV_E00281',
@@ -421,10 +414,10 @@ class IsFreeSurferTimewiseConsistent(ExperimentTest):
 
 
 class ReconAllAsegSnapshot(ExperimentTest, Snapshot):
-    '''This generates a snapshot of the results generated by FREESURFER6
-    focusing on central subcortical structures.
-    Passes if the snapshot is created successfully. Fails otherwise. Does not
-    tell anything on the segmentation quality. '''
+    """This test creates a snapshot of the results generated by FREESURFER6
+    focusing on central subcortical structures. Passes if the snapshot is
+    created successfully. Fails otherwise. Does not tell anything on the
+    segmentation quality."""
 
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E00754',  # has no FreeSurfer6 resource
@@ -461,10 +454,10 @@ class ReconAllAsegSnapshot(ExperimentTest, Snapshot):
 
 
 class ReconAllAparcSnapshot(ExperimentTest, Snapshot):
-    '''This generates a snapshot of the results generated by FREESURFER6
-    focusing on cortical areas and others (CSF, corpus callosum).
-    Passes if the snapshot is created successfully. Fails otherwise. Does not
-    tell anything on the segmentation quality. '''
+    """This test creates a snapshot of the results generated by FREESURFER6
+    focusing on cortical areas and others (CSF, corpus callosum). Passes if the
+    snapshot is created successfully. Fails otherwise. Does not tell anything on
+    the segmentation quality."""
 
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E00754',  # has no FreeSurfer6 resource
@@ -502,9 +495,9 @@ class ReconAllAparcSnapshot(ExperimentTest, Snapshot):
 
 
 class AreCAVolumesConsistent(ExperimentTest):
-    ''' Validates that the volumes of the _Cornu Ammonis_ main subregions from
-    FreeSurfer hippocampal segmentation results (any mode) are consistent in size.
-    Passes if `CA1` > `CA4` > `CA3` and fails otherwise.'''
+    """Checks that CA1, CA2 and CA3 (_Cornu Ammonis_ areas) display the  
+    expected order in volumes in the resulting segmentation.
+    consistent in size. Passes if `CA1` > `CA4` > `CA3` and fails otherwise."""
 
     passing = 'BBRCDEV_E00013',
     failing = 'BBRCDEV_E00281',
@@ -552,12 +545,12 @@ class AreCAVolumesConsistent(ExperimentTest):
 
 
 class HasAbnormalAsegFeatures(ExperimentTest):
-    ''' Controls whether FreeSurfer-generated `aseg` features are within target
+    """Checks whether FreeSurfer-generated `aseg` features are within target
     intervals defined by 99th-percentiles of a sample distribution (estimated
-    on all results from ALFA_OPCIONAL and ALFA_PLUS). Features include
+    on all results from ALFA_OPCIONAL and ALFA_PLUS projects). Features include
     raw volumes and standard deviation of intensity values measured over each
     region's mask. Passes if less than 5 regions show abnormal values (counting
-    both volumes and std). Fails otherwise.'''
+    both volumes and std). Fails otherwise."""
 
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E02443',
