@@ -138,9 +138,9 @@ class HasThumbnails(ScanTest):
 
 
 class HasNifti(ScanTest):
-    """Datasets are automatically converted to NIfTI (depends on projects).
-    Passes if the sequence has an existing NIfTi version. Fails if NIfTI is
-    missing."""
+    """Datasets are automatically converted to NIfTI (depending on project
+    configuration). Test passes if the given scan has an existing NIfTI resource.
+    Fails if NIfTI resource is missing."""
 
     passing = 'BBRCDEV_E00007', '301'
     failing = 'BBRCDEV_E00021', '101'
@@ -289,7 +289,7 @@ class HasPhilipsPrivateTags(ScanTest):
 
 class HasRescaleParameters(ScanTest):
     """Passes if the scan has `Rescale Intercept` and `Rescale Slope` parameters
-    in the headers of its first DICOM file, stored either as public or private
+    in the headers of its first DICOM file stored either as public or private
     DICOM fields. Fails otherwise."""
 
     passing = 'BBRCDEV_E00754', '501'
@@ -403,9 +403,9 @@ class HasRescaleParametersInScans(ExperimentTest):
 
 
 class HasBvecBval(ScanTest):
-    """Diffusion-weighted datasets should have a BVEC and a BVAL file generated
-    by the conversion to NIfTI. Passes if the dataset has existing and non-empty
-    BVEC and BVAL items. Fails otherwise."""
+    """Diffusion-weighted datasets should have a BVEC and a BVAL pair of files
+    generated by the conversion to NIfTI. Test passes if the dataset has such
+    files with non-empty BVEC and BVAL values. Fails otherwise."""
 
     passing = 'BBRCDEV_E00014', '1501'
     failing = 'BBRCDEV_E00015', '1301'
@@ -472,9 +472,10 @@ class HasBvecBval(ScanTest):
 
 
 class HasBvecBvalInDWIScans(ExperimentTest):
-    """Diffusion-weighted datasets should have a BVEC and a BVAL file generated
-    by the conversion to NIfTI. Passes if the dataset has existing and non-empty
-    BVEC and BVAL items or simply no DWI/DTI scans included. Fails otherwise."""
+    """Diffusion-weighted datasets should have a BVEC and a BVAL pair of files
+    generated by the conversion to NIfTI. Test passes if the dataset has such
+    files with non-empty BVEC and BVAL values or simply no DWI/DTI scans included.
+    Fails otherwise."""
 
     passing = 'BBRCDEV_E00014',
     failing = 'BBRCDEV_E00007',
@@ -900,9 +901,9 @@ class HasCorrectSequenceAttributes(ExperimentTest):
 
 
 class IsFreeSurferRunnable(ExperimentTest):
-    """This check validates that the given MRSession fulfills the requirements
-    for running FreeSurfer application. Fails if no MRSession scans are suited
-    for running FreeSurfer (see result/report data), passes otherwise."""
+    """This test validates that the given MRSession fulfills the requirements
+    for running FreeSurfer. Fails if no MRSession scans are suited for running
+    FreeSurfer (see result/report data); passes otherwise."""
 
     passing = 'BBRCDEV_E00375',
     failing = 'BBRCDEV_E00483',
@@ -1327,7 +1328,7 @@ class HasValidAccessionNumber(ExperimentTest):
 
 
 class IsDtifitRunnable(ExperimentTest):
-    """This check validates that the given MRSession fulfills the requirements
+    """This test validates that the given MRSession fulfills the requirements
     for running FSL dtifit application. Fails if no MRSession scans are suited
     for running dtifit (see result/report data), passes otherwise."""
 
@@ -1529,7 +1530,7 @@ class IsASHSRunnable(ExperimentTest):
     """This test validates that the given MRSession fulfills the requirements
     to run `ASHS`, a multimodal pipeline for the segmentation of hippocampal
     subfields that uses a T1w and a Inversion Recovery (IR) set of scan images.
-    Fails if no MRSession scans are suited for running `ASHS` pipeline, passes
+    Fails if no MRSession scans are suited for running `ASHS` pipeline; passes
     otherwise."""
 
     passing = 'BBRCDEV_E02443',
@@ -1645,7 +1646,7 @@ class HasValidDcm2niixVersion(ExperimentTest):
 
 
 class IsAcquisitionDateConsistent(ExperimentTest):
-    """ A session is composed of a set of scans (images) acquired at specific
+    """A session is composed of a set of scans (images) acquired at specific
     timepoints, usually (but not mandatorily) all on the same day. This test
     checks whether the date of an imaging session is consistent across its scans,
     comparing the session `date` attribute (XNAT) with the `AcquisitionDate`
