@@ -164,7 +164,7 @@ class IsScannerVersionCorrect(ExperimentTest):
 
 class IsSubjectIdCorrect(ExperimentTest):
     """PET scans are acquired in an external site and the internal volunteer IDs
-    are afterwards assigned folling a (pseudo)manually procedure highly sensitive
+    are afterwards assigned following a (pseudo)manually procedure highly sensitive
     to human errors at data entry. This test checks if the Subject ID is valid,
     i.e. composed by 5 numeric digits. Fails otherwise."""
 
@@ -186,7 +186,7 @@ class IsSubjectIdCorrect(ExperimentTest):
 
 
 class IsSubjectWeightConsistent(ExperimentTest):
-    """ Check if subject's weight is registered in the DICOM header and if the
+    """Check if subject's weight is registered in the DICOM header and if the
     value represents a realistic weight, i.e. ranges between 40 and 150 kgs.
     Fails otherwise."""
 
@@ -285,7 +285,8 @@ class HasUsableT1(ExperimentTest):
             return Results(False, ['No MR sessions found.'])
 
         # discard MRIs where project is not from the list
-        included_projects = ['ALFA_PLUS', 'ALFA_OPCIONAL', 'testenv']
+        included_projects = ['ALFA_PLUS', 'ALFA_OPCIONAL',
+                             'ALFA_PLUS2', 'EPAD', 'testenv']
         valid_mris = [i for i in mris if i['project'] in included_projects]
 
         candidate_t1s = []
