@@ -237,7 +237,8 @@ class DTIFITValidator(Validator):
                  dtifit.HasCorrectFSLVersion,
                  dtifit.DTIFITSnapshotFA,
                  dtifit.DTIFITSnapshotRGB,
-                 dtifit.DTIFITSnapshotTOPUP]
+                 dtifit.DTIFITSnapshotTOPUP,
+                 dtifit.HasFewNegativeVoxelsInMD]
         super(type(self), self).__init__(tests, lut, xnat_instance)
 
 
@@ -333,4 +334,13 @@ class BAMOSValidator(Validator):
                  bamos.LesionSegmentationSnapshot,
                  bamos.LobesSegmentationSnapshot,
                  bamos.LayersSegmentationSnapshot]
-        super(type(self), self).__init__(tests, lut, xnat_instance)
\ No newline at end of file
+        super(type(self), self).__init__(tests, lut, xnat_instance)
+
+
+class DONSURFValidator(Validator):
+    def __init__(self, lut, xnat_instance):
+        from bbrc.validation.processing import donsurf
+        tests = [donsurf.HasCorrectItems,
+                 donsurf.HasCorrectFreeSurferVersion,
+                 donsurf.DWIRegistrationSnapshot]
+        super(type(self), self).__init__(tests, lut, xnat_instance)
